Skip to contents

Quick check to determine if any sample names match recognized standards.

Usage

is_standard(sample_names)

Arguments

sample_names

Character vector of sample names.

Value

Logical vector indicating whether each name matches a standard.

Examples

is_standard(c("PS A", "Unknown", "PMMA-B"))
#> [1]  TRUE FALSE  TRUE