Quick check to determine if any sample names match recognized standards.
Examples
is_standard(c("PS A", "Unknown", "PMMA-B"))
#> [1] TRUE FALSE TRUE
Quick check to determine if any sample names match recognized standards.
is_standard(c("PS A", "Unknown", "PMMA-B"))
#> [1] TRUE FALSE TRUE