Creates a calibration curve plot from SEC calibration data or a prepped recipe with conventional calibration.
Usage
plot_sec_calibration(
data,
retention_col = "retention_time",
mw_col = "log_mp",
show_residuals = FALSE,
show_r_squared = TRUE,
...
)Arguments
- data
Either:
A data frame of calibration standards with retention and log_mw columns
A prepped recipe containing a conventional calibration step
- retention_col
Name of retention time/volume column. Default is
"retention_time".- mw_col
Name of log MW column. Default is
"log_mp".- show_residuals
Logical. Show residual plot below? Default is
FALSE.- show_r_squared
Logical. Show R-squared value? Default is
TRUE.- ...
Additional arguments passed to
ggplot2::geom_point().
See also
Other sec-visualization:
autoplot.sec_results(),
plot_sec(),
plot_sec_chromatogram(),
plot_sec_composition(),
plot_sec_conformation(),
plot_sec_multidetector(),
plot_sec_mwd(),
sec_results()